#define QT_FEATURE_wayland_client 1
#define QT_FEATURE_egl_extension_platform_wayland 1
#define QT_FEATURE_wayland_brcm -1
#define QT_FEATURE_wayland_client_fullscreen_shell_v1 1
#define QT_FEATURE_wayland_client_ivi_shell 1
#define QT_FEATURE_wayland_client_primary_selection 1
#define QT_FEATURE_wayland_client_wl_shell 1
#define QT_FEATURE_wayland_client_xdg_shell 1
#define QT_FEATURE_wayland_client_xdg_shell_v5 1
#define QT_FEATURE_wayland_client_xdg_shell_v6 1
#define QT_FEATURE_wayland_datadevice 1
#define QT_FEATURE_wayland_dmabuf_server_buffer 1
#define QT_FEATURE_wayland_drm_egl_server_buffer 1
#define QT_FEATURE_wayland_egl 1
#define QT_FEATURE_wayland_libhybris_egl_server_buffer -1
#define QT_FEATURE_wayland_shm_emulation_server_buffer 1
#define QT_FEATURE_wayland_vulkan_server_buffer 1
#define QT_FEATURE_xcomposite_egl 1
#define QT_FEATURE_xcomposite_glx 1
